from rest_framework.test import APITestCase
from rest_framework import status
from django.urls import reverse
from arkindex.dataimport.models import DataImport, DataImportMode, DataImportState
from arkindex.documents.models import Corpus
from arkindex.users.models import User


class TestImports(APITestCase):
    """
    Test data imports management
    """

    def setUp(self):
        self.corpus = Corpus.objects.create(id='test', name='Unit Tests')
        self.user = User.objects.create_user('test@test.test', 'testtest')
        self.dataimport = DataImport.objects.create(
            creator=self.user, corpus=self.corpus, mode=DataImportMode.Images)

    def test_list_requires_login(self):
        response = self.client.get(reverse('api:import-list'))
        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)

    def test_list(self):
        self.client.force_login(self.user)
        response = self.client.get(reverse('api:import-list'))
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertEqual(len(data['results']), 1)
        result = data['results'][0]
        self.assertEqual(result['id'], str(self.dataimport.id))
        self.assertEqual(result['state'], DataImportState.Created.value)
        self.assertEqual(result['mode'], DataImportMode.Images.value)
        self.assertEqual(result['corpus'], str(self.corpus.id))

    def test_details_requires_login(self):
        response = self.client.get(reverse('api:import-details', kwargs={'pk': self.dataimport.id}))
        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)

    def test_details(self):
        self.client.force_login(self.user)
        response = self.client.get(reverse('api:import-details', kwargs={'pk': self.dataimport.id}))
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertEqual(data['id'], str(self.dataimport.id))
