from urllib.parse import urlsplit, SplitResult
from django.conf import settings
import Levenshtein
import random
import string
import re


def sslify_url(url):
    """Build a sslified URL if needed."""
    splat = urlsplit(url)

    if settings.SSLIFY_HOST is None or \
            len(settings.SSLIFY_HOST) < 1 or \
            splat.scheme != "http":
        return url

    return SplitResult(
        'https',
        settings.SSLIFY_HOST,
        splat.netloc + splat.path,
        splat.query,
        splat.fragment
    ).geturl()


def random_string(n):
    '''
    Build a random chars string of length n
    '''
    return ''.join([
        random.choice(string.ascii_letters + string.digits)
        for _ in range(n)
    ])


ES_ESCAPE_REGEX = re.compile(r'([+\-=\\><!(){}\[\]^"~*?:/]|\|\||&&)')


def elasticsearch_escape(s):
    '''
    Escape a string for use by ElasticSearch
    https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-query-string-query.html#_reserved_characters # noqa
    '''
    def replace(matchobj):
        if matchobj.group(0) in ['<', '>']:
            return ''
        if matchobj.group(0) == '\\':
            return '\\\\'
        if matchobj.group(0) == '"':
            return '\\\\\\"'
        return '\\\\' + matchobj.group(0)

    return ES_ESCAPE_REGEX.sub(replace, s)


def find_closest(name, queryset, min_ratio=0.8):
    '''
    Find closest element using Levenshtein distance
    '''
    assert isinstance(name, str)

    scores = sorted([
        (element, Levenshtein.ratio(name, element.name))
        for element in queryset
    ], key=lambda x: x[1], reverse=True)

    best_element, best_score = scores[0]
    if best_score >= min_ratio:
        return best_element
